'use strict';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation. All rights reserved.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use
this file except in compliance with the License. You may obtain a copy of the
License at http://www.apache.org/licenses/LICENSE-2.0

THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
MERCHANTABLITY OR NON-INFRINGEMENT.

See the Apache Version 2.0 License for specific language governing permissions
and limitations under the License.
***************************************************************************** */

function __spreadArrays() {
    for (var s = 0, i = 0, il = arguments.length; i < il; i++) s += arguments[i].length;
    for (var r = Array(s), k = 0, i = 0; i < il; i++)
        for (var a = arguments[i], j = 0, jl = a.length; j < jl; j++, k++)
            r[k] = a[j];
    return r;
}

var StoreEnum;
(function (StoreEnum) {
    StoreEnum["prefix"] = "deliveryman__";
})(StoreEnum || (StoreEnum = {}));
var StoreEnum$1 = StoreEnum;

var Store = (function () {
    function Store() {
    }
    Store.prototype.write = function (key, value) {
        sessionStorage.setItem(key, value);
        return sessionStorage.getItem(key) === value;
    };
    Store.prototype.read = function (key) {
        return sessionStorage.getItem(key);
    };
    Store.prototype.remove = function (key) {
        sessionStorage.removeItem(key);
        return !!sessionStorage.getItem(key);
    };
    Store.prototype.removeAll = function () {
        var _arr = __spreadArrays(new Array(sessionStorage.length));
        _arr.forEach(function (v, index) {
            var _key = sessionStorage.key(index);
            if (_key && _key.match(StoreEnum$1.prefix)) {
                sessionStorage.removeItem(_key);
            }
        });
        return _arr.some(function (v, index) {
            var _key = sessionStorage.key(index);
            if (_key)
                return !!_key.match(StoreEnum$1.prefix);
            return false;
        });
    };
    return Store;
}());

var store = new Store();
var Deliveryman = (function () {
    function Deliveryman(options) {
        this.callbacks = null;
        store.removeAll();
        if (options && !options.withoutListen)
            this.hire();
    }
    Deliveryman.prototype.hire = function () {
        window.addEventListener('message', this.work.bind(this));
    };
    Deliveryman.prototype.work = function (event) {
        var _this = this;
        if (!event.data)
            return;
        var keys = Object.keys(event.data);
        keys.forEach(function (key) {
            if (!key.match(StoreEnum$1.prefix))
                return;
            store.write(key, JSON.stringify(event.data[key]));
            if (_this.callbacks && _this.callbacks[key])
                _this.callbacks[key](event.data[key]);
        });
    };
    Deliveryman.prototype.delivering = function (key, callback) {
        if (!this.callbacks)
            this.callbacks = {};
        this.callbacks[StoreEnum$1.prefix + key] = callback;
    };
    Deliveryman.prototype.send = function (key, data) {
        var _a;
        window.parent.postMessage((_a = {}, _a[StoreEnum$1.prefix + key] = data, _a), '*');
    };
    Deliveryman.prototype.receive = function (key) {
        return JSON.parse(store.read(StoreEnum$1.prefix + key) || '') || null;
    };
    Deliveryman.prototype.delete = function (key) {
        store.remove(StoreEnum$1.prefix + key);
        return !!store.read(StoreEnum$1.prefix + key);
    };
    Deliveryman.prototype.fire = function () {
        window.removeEventListener('message', this.work.bind(this));
    };
    return Deliveryman;
}());

module.exports = Deliveryman;
//# sourceMappingURL=index.cjs.js.map
